from .bookkeeping import get_token, get_ifta_trip_id, get_tax_info, send_ifta_data, update_tax_info
from .rpa import get_rpa_token
from .auto import duke_auto, rpa_auto, ralock_auto
from .ocr import duke_ocr



import requests
# from dukeai._config._config import


def get_rpa_token(username, password):
    url = "https://api.duke.ai/token/get_token"

    headers = {
              'username': username.upper(),
              'password': password
             }

    response = requests.request("GET", url, headers=headers)

    return response.json
